import { AppConfiguration } from './AppConfiguration';
import { Registration } from '@ts-ioc/core';
/**
 * Inject ApplicationToken
 *
 * @export
 * @class InjectApplicationToken
 * @extends {Registration<T>}
 * @template T
 */
export declare class InjectApplicationToken<T extends IApplication> extends Registration<T> {
    constructor(desc: string);
    static classAnnations: any;
}
/**
 * Default Application Token.
 */
export declare const ApplicationToken: InjectApplicationToken<IApplication>;
/**
 * application.
 *
 * @export
 * @interface IApplication
 */
export interface IApplication {
    /**
     * application configuration.
     *
     * @type {AppConfiguration<any>}
     * @memberof IApplication
     */
    config?: AppConfiguration<any>;
}
/**
 * on Application start.
 *
 * @export
 * @interface OnStart
 * @template T
 */
export interface OnApplicationStart<T extends IApplication> {
    /**
     * on application start.
     *
     * @param {T} instance
     * @memberof OnStart
     */
    onStart(instance: T): void | Promise<any>;
}
/**
 * on Application started.
 *
 * @export
 * @interface OnStart
 * @template T
 */
export interface OnApplicationStarted<T extends IApplication> {
    /**
     * on application onStarted.
     *
     * @param {T} instance
     * @memberof OnStart
     */
    onStarted(instance: T): void;
}
